@@ -1,13 +1,14 @@
 use std::{fs::OpenOptions, io::Read};
-
 use enums::Token;
 
-mod enums;
+pub mod lexer;
+pub mod enums;
+
 #[allow(unused_imports)]
 #[warn(missing_docs)]
-mod lexer;
-
-pub fn read_template(path: &str) -> Result<String, std::io::Error> {
+ 
+ 
+fn read_template(path: &str) -> Result<String, std::io::Error> {
     let mut f = OpenOptions::new()
         .read(true)
         .write(false)
@@ -29,8 +30,20 @@ pub fn read_template(path: &str) -> Result<String, std::io::Error> {
     Ok(page.to_string())
 }
 
-pub fn test_me() -> Vec<Token> {
-    let path = "/Users/matthew/dev/projects/script-homebrew/temp.txt";
+/// Constructs a vector of tokens.
+/// This straight forward lexical scanner is preset to support over 75 tokens.  The list of tokens can be found at this sites
+/// github page. 
+/// Usually, this is the main method for generating tokens by passing in a file path to the document you want to perform a lexical scan on.
+/// Example
+/// ``` rust 
+/// pub use lexical_scanner::*;
+/// pub use enums::*;
+/// let path = "./test/test.txt";
+/// let token_list = lexical_scanner::lexer(path);
+/// println!("{:?}, ", token_list);
+/// ```
+/// 
+pub fn lexer(path: &str) -> Vec<Token> {
     let this = read_template(path);
 
     if let Ok(page) = this {
@@ -39,14 +52,10 @@ pub fn test_me() -> Vec<Token> {
         let mut token_container = vec![];
         let tokenizer = lexer::lexer::lexer::Tokenizer::new(&tmp);
 
-        let mut i = 0;
-        println!("2233");
-        //while let Some(token) = tokenizer.next() {
         for token in tokenizer {
             match Some(token) {
                 Some(t) => match t {
                     enums::Token::Undefined => break,
-                    enums::Token::WhiteSpace => {}
                     _ => {
                         //println!("{}. {:?}", i, t);
                         token_container.push(t);
@@ -54,25 +63,50 @@ pub fn test_me() -> Vec<Token> {
                 },
                 None => break,
             }
-            i += 1;
-
-            if i > 100000 {
-                break;
-            }
         }
 
         return token_container;
     }
 
-    println!("223");
-
     vec![]
 }
 
+/// Constructs a vector of tokens.
+/// This straight forward lexical scanner is preset to support over 75 tokens.  The list of tokens can be found at this sites
+/// github page. 
+/// Usually, passing in a text string is used for debugging and testing.
+/// Example
+/// ``` rust 
+/// pub use lexical_scanner::*;
+/// pub use enums::*;
+/// let text = "The number 5.0 is > 1;";
+/// let token_list = lexical_scanner::lexer_as_str(text); 
+/// ```
+/// 
+pub fn lexer_as_str(text: &str) -> Vec<Token> {
+    let mut token_container = vec![];
+    let tokenizer = lexer::lexer::lexer::Tokenizer::new(&text);
+
+    for token in tokenizer {
+        match Some(token) {
+            Some(t) => match t {
+                enums::Token::Undefined => break,
+                _ => {
+                    //println!("{}. {:?}", i, t);
+                    token_container.push(t);
+                }
+            },
+            None => break,
+        }
+    }
+
+    return token_container;
+}
+
 // Unit tests
 #[cfg(test)]
 mod unit_test {
-    use super::*;
+    //zuse super::*;
     use crate::{enums::Token, lexer::lexer::lexer::Tokenizer};
 
     #[test]
